pipolars.DataQuality - PIPolars 0.1.0 documentation

Skip to content
Back to top
View this page
Edit this page

# pipolars.DataQuality

class pipolars.DataQuality

  Bases: `IntEnum`

  PI data quality flags.

  These flags indicate the quality and reliability of PI values.

  __init__(*args, **kwds)

  Methods

  `conjugate`() | Returns self, the complex conjugate of any int.
  `bit_length`() | Number of bits necessary to represent self in binary.
  `bit_count`() | Number of ones in the binary representation of the absolute value of self.
  `to_bytes`([length, byteorder, signed]) | Return an array of bytes representing an integer.
  `from_bytes`(bytes[, byteorder, signed]) | Return the integer represented by the given array of bytes.
  `as_integer_ratio`() | Return a pair of integers, whose ratio is equal to the original int.
  `is_integer`() | Returns True.
  `__init__`(*args, **kwds) |

  Attributes

  `real` | the real part of a complex number
  `imag` | the imaginary part of a complex number
  `numerator` | the numerator of a rational number in lowest terms
  `denominator` | the denominator of a rational number in lowest terms
  `GOOD` | Value is good and reliable.
  `SUBSTITUTED` | Value was manually substituted.
  `QUESTIONABLE` | Value quality is questionable.
  `BAD` | Value is bad or unreliable.
  `NO_DATA` | No data available for the requested time.
  `CALC_FAILED` | Calculation failed to produce a value.

  GOOD = 0

    Value is good and reliable.

  SUBSTITUTED = 1

    Value was manually substituted.

  QUESTIONABLE = 2

    Value quality is questionable.

  BAD = 3

    Value is bad or unreliable.

  NO_DATA = 4

    No data available for the requested time.

  CALC_FAILED = 5

    Calculation failed to produce a value.

  __new__(value)